from django_filters import rest_framework as filters
from django_celery_results.models import TaskResult, TASK_STATE_CHOICES, GroupResult


class TaskResultFilter(filters.FilterSet):
    periodic_task_name = filters.CharFilter(lookup_expr='icontains')
    task_name = filters.CharFilter(lookup_expr='icontains')
    task_args = filters.CharFilter(lookup_expr='icontains')
    task_kwargs = filters.CharFilter(lookup_expr='icontains')
    status = filters.ChoiceFilter(choices=TASK_STATE_CHOICES)
    worker = filters.CharFilter(lookup_expr='icontains')
    date_done = filters.DateTimeFromToRangeFilter()

    class Meta:
        model = TaskResult
        fields = {'task_id': ['icontains']}


class GroupResultFilter(filters.FilterSet):
    date_done = filters.DateTimeFromToRangeFilter()
    group_id = filters.CharFilter(lookup_expr='icontains')

    class Meta:
        model = GroupResult
        fields = ['date_done', 'group_id']



from django.contrib import admin
from rest_framework import serializers
from django_celery_results.models import TaskResult, TASK_STATE_CHOICES, GroupResult
from django_celery_results.admin import TaskResultAdmin


class TaskResultSerializer(serializers.ModelSerializer):
    status = serializers.ChoiceField(choices=TASK_STATE_CHOICES)

    class Meta:
        model = TaskResult
        fields = '__all__'
        read_only_fields = TaskResultAdmin(TaskResult, admin_site=admin.site).get_readonly_fields(None)


class TaskResultListSerializer(serializers.ModelSerializer):
    class Meta:
        model = TaskResult
        fields = ['task_id', 'periodic_task_name', 'task_name', 'date_done', 'status', 'worker']


class GroupResultSerializer(serializers.ModelSerializer):
    class Meta:
        model = GroupResult
        fields = '__all__'
        read_only_fields = ['date_created', 'date_done', 'result']


class GroupResultListSerializer(serializers.ModelSerializer):
    class Meta:
        model = GroupResult
        fields = ['group_id', 'date_done']



from rest_framework import viewsets
from rest_framework.filters import OrderingFilter
from django_filters import rest_framework as filters
from django_celery_results.models import TaskResult, GroupResult

from .serializers import (
    TaskResultSerializer, TaskResultListSerializer, GroupResultSerializer, GroupResultListSerializer
)
from .filters import TaskResultFilter, GroupResultFilter


class TaskResultViewSet(viewsets.ModelViewSet):
    queryset = TaskResult.objects.all()
    serializer_class = TaskResultSerializer
    filter_backends = [OrderingFilter, filters.DjangoFilterBackend]
    filterset_class = TaskResultFilter
    ordering_fields = ['id']

    def get_serializer_class(self):
        if self.action == 'list':
            return TaskResultListSerializer
        else:
            return TaskResultSerializer


class GroupResultViewSet(viewsets.ModelViewSet):
    queryset = GroupResult.objects.all()
    serializer_class = GroupResultSerializer
    filter_backends = [OrderingFilter, filters.DjangoFilterBackend]
    filterset_class = GroupResultFilter
    ordering_fields = ['id']

    def get_serializer_class(self):
        if self.action == 'list':
            return GroupResultListSerializer
        else:
            return GroupResultSerializer



from setuptools import find_packages, setup


with open('README.md', 'r') as fh:
    readme = fh.read()

setup(
    name='django-celery-results-rest',
    version='0.0.1',
    license='MIT',
    author='zengqiu',
    author_email='zengqiu@qq.com',
    description='RESTful API for django-celery-results',
    long_description=readme,
    long_description_content_type='text/markdown',
    packages=find_packages(),
    platforms='any',
    include_package_data=True,
    install_requires=['django-celery-results>=2.5.1', 'djangorestframework>=3.14.0', 'django-filter>=23.5'],
    python_requires='>=3.5',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)


from django.urls import path, include
from rest_framework.routers import DefaultRouter
from . import views


router = DefaultRouter()
router.register(r'taskresults', views.TaskResultViewSet)
router.register(r'groupresults', views.GroupResultViewSet)

urlpatterns = [
    path('', include(router.urls))
]
